import unittest
import tempfile
import os
from ex1 import read_settings, write_to_file


class TestSettings(unittest.TestCase):
    def setUp(self):
        self.tempfile = tempfile.NamedTemporaryFile(delete=False)
        with open(self.tempfile.name, 'w') as file:
            file.write("[database]\nhost = localhost\nport = 3306\nuser = user\npassword = secret")

    def tearDown(self):
        os.remove(self.tempfile.name)

    def test_read_settings(self):
        settings = read_settings(self.tempfile.name)
        self.assertEqual(settings['host'], 'localhost')
        self.assertEqual(settings['port'], 3306)
        self.assertEqual(settings['user'], 'user')
        self.assertEqual(settings['password'], 'secret')

    def test_file_not_found_error(self):
        with self.assertRaises(FileNotFoundError):
            read_settings('nonexistent.ini')

    def test_value_error(self):
        with open(self.tempfile.name, 'w') as file:
            file.write("invalid content")
        with self.assertRaises(ValueError):
            read_settings(self.tempfile.name)


class TestFileWrite(unittest.TestCase):
    def setUp(self):
        self.tempfile = tempfile.NamedTemporaryFile(delete=False)
        self.tempfile.close()

    def tearDown(self):
        os.remove(self.tempfile.name)

    def test_write_to_file(self):
        write_to_file(self.tempfile.name, "Hello")
        with open(self.tempfile.name, 'r') as file:
            content = file.read().strip()
        self.assertEqual(content, "Hello")

    def test_append_to_file(self):
        write_to_file(self.tempfile.name, "First line")
        write_to_file(self.tempfile.name, "Second line")
        with open(self.tempfile.name, 'r') as file:
            content = file.read().strip().split('\n')
        self.assertEqual(content, ["First line", "Second line"])

    def test_create_file_if_absent(self):
        os.remove(self.tempfile.name)  # Удаляем файл
        write_to_file(self.tempfile.name, "New content")
        with open(self.tempfile.name, 'r') as file:
            content = file.read().strip()
        self.assertEqual(content, "New content")


if __name__ == '__main__':
    unittest.main()
